aboutsummaryrefslogtreecommitdiff
path: root/src/indexamajig.c
diff options
context:
space:
mode:
authorThomas White <taw@physics.org>2010-01-19 17:40:19 +0100
committerThomas White <taw@physics.org>2010-01-19 17:40:19 +0100
commita4c5daf2f0f37577798af0de5cd31dc81f87eec5 (patch)
treee3ea444c9516e2045c8ab6cf6ee5743bd1ac383b /src/indexamajig.c
parentb04befccb98fe1bf32829168c8f95b7762b8162e (diff)
Use "fine" peak search for hit finding (it's fast enough)
Diffstat (limited to 'src/indexamajig.c')
-rw-r--r--src/indexamajig.c36
1 files changed, 20 insertions, 16 deletions
diff --git a/src/indexamajig.c b/src/indexamajig.c
index 17151581..3cd3a408 100644
--- a/src/indexamajig.c
+++ b/src/indexamajig.c
@@ -117,7 +117,6 @@ int main(int argc, char *argv[])
char line[1024];
struct hdfile *hdfile;
struct image image;
- int fom;
rval = fgets(line, 1023, fh);
if ( rval == NULL ) continue;
@@ -141,26 +140,31 @@ int main(int argc, char *argv[])
hdf5_read(hdfile, &image);
- fom = image_fom(&image);
- if ( fom > 0 ) {
+ /* Perform 'fine' peak search */
+ search_peaks(&image, config_dumpfound);
- /* Calculate orientation matrix (by magic) */
- index_pattern(&image, config_noindex, config_dumpfound,
- config_dirax);
+ if ( image_feature_count(image.features) > 25 ) {
- if ( image.molecule == NULL ) goto done;
+ n_hits++;
- /* View head-on (unit cell is tilted) */
- image.orientation.w = 1.0;
- image.orientation.x = 0.0;
- image.orientation.y = 0.0;
- image.orientation.z = 0.0;
- get_ewald(&image);
+ if ( !config_noindex ) {
- /* Read h,k,l,I */
- output_intensities(&image);
+ /* Calculate orientation matrix (by magic) */
+ index_pattern(&image, config_noindex,
+ config_dirax);
- n_hits++;
+ if ( image.molecule == NULL ) goto done;
+
+ /* View head-on (unit cell is tilted) */
+ image.orientation.w = 1.0;
+ image.orientation.x = 0.0;
+ image.orientation.y = 0.0;
+ image.orientation.z = 0.0;
+ get_ewald(&image);
+
+ /* Read h,k,l,I */
+ output_intensities(&image);
+ }
}